/*
 * Copyright (c) 2008 Jesper Karlsson & David Gustafsson
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __XFBIB_BIBTEX_FIELD_H
#define __XFBIB_BIBTEX_FIELD_H

#include <glib-object.h>
#include <libxfce4ui/libxfce4ui.h>
#include "xfbib-bibtex-value.h"

#define XFBIB_TYPE_BIBTEX_FIELD             (xfbib_bibtex_field_get_type())
#define XFBIB_BIBTEX_FIELD(obj)             (G_TYPE_CHECK_INSTANCE_CAST((obj), XFBIB_TYPE_BIBTEX_FIELD, XfbibBibtexField))
#define XFBIB_IS_BIBTEX_FIELD(obj)          (G_TYPE_CHECK_INSTANCE_TYPE((obj), XFBIB_TYPE_BIBTEX_FIELD))
#define XFBIB_BIBTEX_FIELD_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST((klass), XFBIB_TYPE_BIBTEX_FIELD, XfbibBibtexFieldClass))
#define XFBIB_IS_BIBTEX_FIELD_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE((klass), XFBIB_TYPE_BIBTEX_FIELD))
#define XFBIB_BIBTEX_FIELD_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), XFBIB_TYPE_BIBTEX_FIELD, XfbibBibtexFieldClass))

G_BEGIN_DECLS

enum {
	XFBIB_BIBTEX_FIELD_ADDRESS = 0,
	XFBIB_BIBTEX_FIELD_ANNOTE,
	XFBIB_BIBTEX_FIELD_AUTHOR,
	XFBIB_BIBTEX_FIELD_BOOKTITLE,
	XFBIB_BIBTEX_FIELD_CHAPTER,
	XFBIB_BIBTEX_FIELD_CROSSREF,
	XFBIB_BIBTEX_FIELD_EDITION,
	XFBIB_BIBTEX_FIELD_EDITOR,
	XFBIB_BIBTEX_FIELD_EPRINT,
	XFBIB_BIBTEX_FIELD_HOWPUBLISHED,
	XFBIB_BIBTEX_FIELD_INSTITUTION,
	XFBIB_BIBTEX_FIELD_JOURNAL,
	XFBIB_BIBTEX_FIELD_KEY,
	XFBIB_BIBTEX_FIELD_MONTH,
	XFBIB_BIBTEX_FIELD_NOTE,
	XFBIB_BIBTEX_FIELD_NUMBER,
	XFBIB_BIBTEX_FIELD_ORGANIZATION,
	XFBIB_BIBTEX_FIELD_PAGES,
	XFBIB_BIBTEX_FIELD_PUBLISHER,
	XFBIB_BIBTEX_FIELD_SCHOOL,
	XFBIB_BIBTEX_FIELD_SERIES,
	XFBIB_BIBTEX_FIELD_TITLE,
	XFBIB_BIBTEX_FIELD_TYPE,
	XFBIB_BIBTEX_FIELD_URL,
	XFBIB_BIBTEX_FIELD_VOLUME,
	XFBIB_BIBTEX_FIELD_YEAR,
	XFBIB_BIBTEX_FIELD_N_FIELDS,
};

struct field_properties {
	gchar *label;
	gchar *tooltip;
};

typedef struct _XfbibBibtexField         XfbibBibtexField;

GType xfbib_bibtex_field_get_type() G_GNUC_CONST;

XfbibBibtexField *xfbib_bibtex_field_new(GObject *);
GObject *xfbib_bibtex_field_get_owner(XfbibBibtexField *);
gboolean xfbib_bibtex_field_parse(XfbibBibtexField *, const gchar *);
const gchar *xfbib_bibtex_field_get_variable(XfbibBibtexField *);
void xfbib_bibtex_field_set_variable(XfbibBibtexField *, const gchar *);
XfbibBibtexValue *xfbib_bibtex_field_get_value(XfbibBibtexField *);
void xfbib_bibtex_field_set_value(XfbibBibtexField *, XfbibBibtexValue *);
#if 0
const gchar *xfbib_bibtex_field_get_value_str(XfbibBibtexField *);
void xfbib_bibtex_field_set_variable(XfbibBibtexField *, const gchar *);
void xfbib_bibtex_field_set_value(XfbibBibtexField *, XfbibBibtexValue *);
gboolean xfbib_bibtex_field_is_column(XfbibBibtexField *, gint);
#endif
G_END_DECLS

#endif //__XFBIB_BIBTEX_FIELD_H

