/* 
 * Copyright (c) 2008 Jesper Karlsson & David Gustafsson
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <gtk/gtk.h>

#include "xfbib-toolbar.h"
#include "xfbib-file-io.h"
#include "xfbib-window.h"
#include "xfbib-state.h"

struct _XfbibToolbar
{
	GtkToolbar parent;
	GtkToolItem *open;
	GtkToolItem *save;
};

static XfbibWindow *window;

typedef struct _XfbibToolbarClass
{
	GtkToolbarClass parent;
} XfbibToolbarClass;

static void xfbib_toolbar_class_init(XfbibToolbarClass *klass);

static void xfbib_toolbar_init(XfbibToolbar *instance);
static void xfbib_toolbar_finalize(GObject *obj);

static GObjectClass *xfbib_toolbar_parent_class = NULL;

static void
cb_open_clicked (GtkButton *buttonitem, gpointer user_data)
{

	XfbibState *state;
	gchar *filename;
	g_print("Toolbar_Open\n");

	state = xfbib_state_new();

	if ((filename = xfbib_file_io_open(NULL)) != NULL) {
		xfbib_state_set_filename(state, filename);
		xfbib_window_set_title(XFBIB_WINDOW(xfbib_state_get_window(state)), filename);
	}
}

static void
cb_save_clicked (GtkButton *buttonitem, gpointer user_data)
{
	XfbibState *state;
	g_print("Toolbar_Save\n");
	state = xfbib_state_new();

	xfbib_file_io_save(xfbib_state_get_filename(state));
}

GType
xfbib_toolbar_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
		static const GTypeInfo info = {
			sizeof (XfbibToolbarClass),
			NULL,   /* base_init */
			NULL,   /* base_finalize */
			(GClassInitFunc) xfbib_toolbar_class_init,   /* class_init */
			NULL,   /* class_finalize */
			NULL,   /* class_data */
			sizeof (XfbibToolbar),
			0,      /* n_preallocs */
			(GInstanceInitFunc) xfbib_toolbar_init    /* instance_init */
		};
		type = g_type_register_static (GTK_TYPE_TOOLBAR, "XfbibToolbar", &info, 0);
	}
	return type;
}

	
static void
xfbib_toolbar_class_init(XfbibToolbarClass *klass)
{
	GObjectClass *object_class = (GObjectClass *)klass;
	
	xfbib_toolbar_parent_class = g_type_class_peek_parent (klass); 

	object_class->finalize = xfbib_toolbar_finalize;
}

static void
xfbib_toolbar_init(XfbibToolbar *instance)
{
	gtk_toolbar_set_orientation (GTK_TOOLBAR (instance), GTK_ORIENTATION_HORIZONTAL);

	instance->open = gtk_tool_button_new_from_stock(GTK_STOCK_OPEN);
	gtk_toolbar_insert (GTK_TOOLBAR (instance), instance->open, -1);
	g_signal_connect (G_OBJECT (instance->open), "clicked", G_CALLBACK (cb_open_clicked), NULL);

	instance->save = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE);
	gtk_toolbar_insert (GTK_TOOLBAR (instance), instance->save, -1);
	g_signal_connect (G_OBJECT (instance->save), "clicked", G_CALLBACK (cb_save_clicked), NULL);
}

static void
xfbib_toolbar_finalize(GObject *obj)
{
	G_OBJECT_CLASS(xfbib_toolbar_parent_class)->finalize(obj);
}

GtkWidget *
xfbib_toolbar_new(XfbibWindow *w)
{
	XfbibToolbar *toolbar;
	toolbar = g_object_new(XFBIB_TYPE_TOOLBAR, NULL);
	window = w;
	return GTK_WIDGET(toolbar);
}

